@@ -168,7 +168,7 @@
     <message>
         <location filename="mainwindow.cpp" line="402"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>À propos %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="403"/>
@@ -188,12 +188,12 @@
     <message>
         <location filename="mainwindow.cpp" line="407"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 Licence</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="422"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Aide</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="430"/>
