@@ -55,7 +55,7 @@
         <location filename="mainwindow.ui" line="256"/>
         <location filename="ui_mainwindow.h" line="340"/>
         <source>Restore original APT sources</source>
-        <translation type="unfinished"/>
+        <translation>Obnoviť pôvodné zdroje APT</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -168,7 +168,7 @@
     <message>
         <location filename="mainwindow.cpp" line="402"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>Okolo %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="403"/>
@@ -188,12 +188,12 @@
     <message>
         <location filename="mainwindow.cpp" line="407"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 Licencia</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="422"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Pomoc</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="430"/>
@@ -203,12 +203,12 @@
     <message>
         <location filename="mainwindow.cpp" line="431"/>
         <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
-        <translation type="unfinished"/>
+        <translation>Vybrali ste MX Test Repo. Neodporúčame ho nechať vybraný alebo aktualizovať z neho balíky.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="432"/>
         <source>A safer option is to install packages individually with MX Package Installer.</source>
-        <translation type="unfinished"/>
+        <translation>Bezpečnejšia možnosť je inštalovať balíky individuálne cez MX Inštalátor balíkov.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="489"/>
@@ -229,7 +229,7 @@
     <message>
         <location filename="mainwindow.cpp" line="595"/>
         <source>Could not download original APT files.</source>
-        <translation type="unfinished"/>
+        <translation>Nemôžem stiahnuť originálne APT súbory.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="609"/>
