@@ -13,7 +13,7 @@
         <location filename="mainwindow.cpp" line="487"/>
         <location filename="ui_mainwindow.h" line="333"/>
         <source>Select the APT repository that you want to use:</source>
-        <translation>Izberite APT repozitorij, ki ga želite uporabljati:</translation>
+        <translation>Izberite APT skladišče, ki ga želite uporabljati:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="59"/>
@@ -178,7 +178,7 @@
     <message>
         <location filename="mainwindow.cpp" line="404"/>
         <source>Program for choosing the default APT repository</source>
-        <translation>Program za določitev privzetega APT repozitorija</translation>
+        <translation>Program za določitev privzetega APT skladišča</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="406"/>
@@ -213,7 +213,7 @@
     <message>
         <location filename="mainwindow.cpp" line="489"/>
         <source>Select the APT repository and sources that you want to use:</source>
-        <translation>Izberite APT repozitorij in vire, ki jih želite uporabljati:</translation>
+        <translation>Izberite APT skladišče in vire, ki jih želite uporabljati:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="538"/>
@@ -263,7 +263,7 @@
     <message>
         <location filename="main.cpp" line="53"/>
         <source>You must run this program as root.</source>
-        <translation>Ta program morate zagnati kot root</translation>
+        <translation>Ta program morate zagnati korensko</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
